@@ -1,5 +1,12 @@
-__version__ = "1.6.2"
+__version__ = "1.9.0"
 
-from queuelib.queue import FifoDiskQueue, LifoDiskQueue
 from queuelib.pqueue import PriorityQueue
+from queuelib.queue import FifoDiskQueue, LifoDiskQueue
 from queuelib.rrqueue import RoundRobinQueue
+
+__all__ = [
+    "FifoDiskQueue",
+    "LifoDiskQueue",
+    "PriorityQueue",
+    "RoundRobinQueue",
+]
