@@ -1,4 +1,6 @@
-import os
+from pathlib import Path
+
+import pytest
 
 from queuelib.pqueue import PriorityQueue
 from queuelib.queue import (
@@ -22,19 +24,19 @@ class PQueueTestMixin:
 
     def test_len_nonzero(self):
         assert not self.q
-        self.assertEqual(len(self.q), 0)
+        assert len(self.q) == 0
         self.q.push(b"a", 3)
         assert self.q
         self.q.push(b"b", 1)
         self.q.push(b"c", 2)
         self.q.push(b"d", 1)
-        self.assertEqual(len(self.q), 4)
+        assert len(self.q) == 4
         self.q.pop()
         self.q.pop()
         self.q.pop()
         self.q.pop()
         assert not self.q
-        self.assertEqual(len(self.q), 0)
+        assert len(self.q) == 0
 
     def test_close(self):
         self.q.push(b"a", 3)
@@ -42,7 +44,7 @@ class PQueueTestMixin:
         self.q.push(b"c", 2)
         self.q.push(b"d", 1)
         iqueues = self.q.queues.values()
-        self.assertEqual(sorted(self.q.close()), [1, 2, 3])
+        assert sorted(self.q.close()) == [1, 2, 3]
         assert all(q.closed for q in iqueues)
 
     def test_close_return_active(self):
@@ -50,82 +52,82 @@ class PQueueTestMixin:
         self.q.push(b"c", 2)
         self.q.push(b"a", 3)
         self.q.pop()
-        self.assertEqual(sorted(self.q.close()), [2, 3])
+        assert sorted(self.q.close()) == [2, 3]
 
     def test_popped_internal_queues_closed(self):
         self.q.push(b"a", 3)
         self.q.push(b"b", 1)
         self.q.push(b"c", 2)
         p1queue = self.q.queues[1]
-        self.assertEqual(self.q.pop(), b"b")
+        assert self.q.pop() == b"b"
         self.q.close()
         assert p1queue.closed
 
 
 class FifoTestMixin:
     def test_push_pop_peek_noprio(self):
-        self.assertEqual(self.q.peek(), None)
+        assert self.q.peek() is None
         self.q.push(b"a")
         self.q.push(b"b")
         self.q.push(b"c")
-        self.assertEqual(self.q.peek(), b"a")
-        self.assertEqual(self.q.pop(), b"a")
-        self.assertEqual(self.q.peek(), b"b")
-        self.assertEqual(self.q.pop(), b"b")
-        self.assertEqual(self.q.peek(), b"c")
-        self.assertEqual(self.q.pop(), b"c")
-        self.assertEqual(self.q.peek(), None)
-        self.assertEqual(self.q.pop(), None)
+        assert self.q.peek() == b"a"
+        assert self.q.pop() == b"a"
+        assert self.q.peek() == b"b"
+        assert self.q.pop() == b"b"
+        assert self.q.peek() == b"c"
+        assert self.q.pop() == b"c"
+        assert self.q.peek() is None
+        assert self.q.pop() is None
 
     def test_push_pop_peek_prio(self):
-        self.assertEqual(self.q.peek(), None)
+        assert self.q.peek() is None
         self.q.push(b"a", 3)
         self.q.push(b"b", 1)
         self.q.push(b"c", 2)
         self.q.push(b"d", 1)
-        self.assertEqual(self.q.peek(), b"b")
-        self.assertEqual(self.q.pop(), b"b")
-        self.assertEqual(self.q.peek(), b"d")
-        self.assertEqual(self.q.pop(), b"d")
-        self.assertEqual(self.q.peek(), b"c")
-        self.assertEqual(self.q.pop(), b"c")
-        self.assertEqual(self.q.peek(), b"a")
-        self.assertEqual(self.q.pop(), b"a")
-        self.assertEqual(self.q.peek(), None)
-        self.assertEqual(self.q.pop(), None)
+        assert self.q.peek() == b"b"
+        assert self.q.pop() == b"b"
+        assert self.q.peek() == b"d"
+        assert self.q.pop() == b"d"
+        assert self.q.peek() == b"c"
+        assert self.q.pop() == b"c"
+        assert self.q.peek() == b"a"
+        assert self.q.pop() == b"a"
+        assert self.q.peek() is None
+        assert self.q.pop() is None
 
 
 class LifoTestMixin:
     def test_push_pop_peek_noprio(self):
-        self.assertEqual(self.q.peek(), None)
+        assert self.q.peek() is None
         self.q.push(b"a")
         self.q.push(b"b")
         self.q.push(b"c")
-        self.assertEqual(self.q.peek(), b"c")
-        self.assertEqual(self.q.pop(), b"c")
-        self.assertEqual(self.q.peek(), b"b")
-        self.assertEqual(self.q.pop(), b"b")
-        self.assertEqual(self.q.peek(), b"a")
-        self.assertEqual(self.q.pop(), b"a")
-        self.assertEqual(self.q.peek(), None)
-        self.assertEqual(self.q.pop(), None)
+        assert self.q.peek() == b"c"
+        assert self.q.pop() == b"c"
+        assert self.q.peek() == b"b"
+        assert self.q.pop() == b"b"
+        assert self.q.peek() == b"a"
+        assert self.q.pop() == b"a"
+        assert self.q.peek() is None
+        assert self.q.pop() is None
 
     def test_push_pop_peek_prio(self):
-        self.assertEqual(self.q.peek(), None)
+        assert self.q.peek() is None
         self.q.push(b"a", 3)
         self.q.push(b"b", 1)
         self.q.push(b"c", 2)
         self.q.push(b"d", 1)
-        self.assertEqual(self.q.peek(), b"d")
-        self.assertEqual(self.q.pop(), b"d")
-        self.assertEqual(self.q.peek(), b"b")
-        self.assertEqual(self.q.pop(), b"b")
-        self.assertEqual(self.q.peek(), b"c")
-        self.assertEqual(self.q.pop(), b"c")
-        self.assertEqual(self.q.peek(), b"a")
-        self.assertEqual(self.q.pop(), b"a")
-        self.assertEqual(self.q.peek(), None)
-        self.assertEqual(self.q.pop(), None)
+        assert self.q.peek() == b"d"
+        assert self.q.pop() == b"d"
+        assert self.q.peek() == b"b"
+        assert self.q.pop() == b"b"
+        assert self.q.peek() == b"c"
+        assert self.q.pop() == b"c"
+        assert self.q.peek() == b"a"
+        assert self.q.pop() == b"a"
+        assert self.q.peek() is None
+        assert self.q.pop() is None
 
 
 class FifoMemoryPriorityQueueTest(PQueueTestMixin, FifoTestMixin, QueuelibTestCase):
@@ -140,27 +142,30 @@ class LifoMemoryPriorityQueueTest(PQueueTestMixin, LifoTestMixin, QueuelibTestCa
 
 class DiskTestMixin:
     def test_nonserializable_object_one(self):
-        self.assertRaises(TypeError, self.q.push, lambda x: x, 0)
-        self.assertEqual(self.q.close(), [])
+        with pytest.raises(TypeError):
+            self.q.push(lambda x: x, 0)
+        assert self.q.close() == []
 
     def test_nonserializable_object_many_close(self):
         self.q.push(b"a", 3)
         self.q.push(b"b", 1)
-        self.assertRaises(TypeError, self.q.push, lambda x: x, 0)
+        with pytest.raises(TypeError):
+            self.q.push(lambda x: x, 0)
         self.q.push(b"c", 2)
-        self.assertEqual(self.q.pop(), b"b")
-        self.assertEqual(sorted(self.q.close()), [2, 3])
+        assert self.q.pop() == b"b"
+        assert sorted(self.q.close()) == [2, 3]
 
     def test_nonserializable_object_many_pop(self):
         self.q.push(b"a", 3)
         self.q.push(b"b", 1)
-        self.assertRaises(TypeError, self.q.push, lambda x: x, 0)
+        with pytest.raises(TypeError):
+            self.q.push(lambda x: x, 0)
         self.q.push(b"c", 2)
-        self.assertEqual(self.q.pop(), b"b")
-        self.assertEqual(self.q.pop(), b"c")
-        self.assertEqual(self.q.pop(), b"a")
-        self.assertEqual(self.q.pop(), None)
-        self.assertEqual(self.q.close(), [])
+        assert self.q.pop() == b"b"
+        assert self.q.pop() == b"c"
+        assert self.q.pop() == b"a"
+        assert self.q.pop() is None
+        assert self.q.close() == []
 
     def test_reopen_with_prio(self):
         q1 = PriorityQueue(self.qfactory)
@@ -169,17 +174,17 @@ class DiskTestMixin:
         q1.push(b"c", 2)
         active = q1.close()
         q2 = PriorityQueue(self.qfactory, startprios=active)
-        self.assertEqual(q2.pop(), b"b")
-        self.assertEqual(q2.pop(), b"c")
-        self.assertEqual(q2.pop(), b"a")
-        self.assertEqual(q2.close(), [])
+        assert q2.pop() == b"b"
+        assert q2.pop() == b"c"
+        assert q2.pop() == b"a"
+        assert not q2.close()
 
 
 class FifoDiskPriorityQueueTest(
     PQueueTestMixin, FifoTestMixin, DiskTestMixin, QueuelibTestCase
 ):
     def qfactory(self, prio):
-        path = os.path.join(self.qdir, str(prio))
+        path = Path(self.qdir, str(prio))
         return track_closed(FifoDiskQueue)(path)
 
 
@@ -187,7 +192,7 @@ class LifoDiskPriorityQueueTest(
     PQueueTestMixin, LifoTestMixin, DiskTestMixin, QueuelibTestCase
 ):
     def qfactory(self, prio):
-        path = os.path.join(self.qdir, str(prio))
+        path = Path(self.qdir, str(prio))
         return track_closed(LifoDiskQueue)(path)
 
 
@@ -195,7 +200,7 @@ class FifoSQLitePriorityQueueTest(
     PQueueTestMixin, FifoTestMixin, DiskTestMixin, QueuelibTestCase
 ):
     def qfactory(self, prio):
-        path = os.path.join(self.qdir, str(prio))
+        path = Path(self.qdir, str(prio))
         return track_closed(FifoSQLiteQueue)(path)
 
 
@@ -203,5 +208,5 @@ class LifoSQLitePriorityQueueTest(
     PQueueTestMixin, LifoTestMixin, DiskTestMixin, QueuelibTestCase
 ):
     def qfactory(self, prio):
-        path = os.path.join(self.qdir, str(prio))
+        path = Path(self.qdir, str(prio))
         return track_closed(LifoSQLiteQueue)(path)
