@@ -1,18 +1,18 @@
-import os
-import glob
+from __future__ import annotations
+
 from abc import abstractmethod
+from typing import Any
 from unittest import mock
-from typing import Any, Optional
 
 import pytest
 
 from queuelib.queue import (
     BaseQueue,
-    FifoMemoryQueue,
-    LifoMemoryQueue,
     FifoDiskQueue,
-    LifoDiskQueue,
+    FifoMemoryQueue,
     FifoSQLiteQueue,
+    LifoDiskQueue,
+    LifoMemoryQueue,
     LifoSQLiteQueue,
 )
 from queuelib.tests import QueuelibTestCase
@@ -20,15 +20,15 @@ from queuelib.tests import QueuelibTestCase
 
 class DummyQueue:
     def __init__(self) -> None:
-        self.q = list()  # type: list
+        self.q: list[Any] = []
 
     def push(self, obj: Any) -> None:
         self.q.append(obj)
 
-    def pop(self) -> Optional[Any]:
+    def pop(self) -> Any | None:
         return self.q.pop() if self.q else None
 
-    def peek(self) -> Optional[Any]:
+    def peek(self) -> Any | None:
         return self.q[-1] if self.q else None
 
     def close(self) -> None:
@@ -41,13 +41,13 @@ class DummyQueue:
 class InterfaceTest(QueuelibTestCase):
     def test_queue(self):
         queue = BaseQueue()
-        with self.assertRaises(NotImplementedError):
+        with pytest.raises(NotImplementedError):
             queue.push(b"")
-        with self.assertRaises(NotImplementedError):
+        with pytest.raises(NotImplementedError):
             queue.peek()
-        with self.assertRaises(NotImplementedError):
+        with pytest.raises(NotImplementedError):
             queue.pop()
-        with self.assertRaises(NotImplementedError):
+        with pytest.raises(NotImplementedError):
             len(queue)
         queue.close()
 
@@ -78,17 +78,19 @@ class InterfaceTest(QueuelibTestCase):
 class QueueTestMixin:
     @abstractmethod
     def queue(self) -> BaseQueue:
-        raise NotImplementedError()
+        raise NotImplementedError
 
     def test_empty(self):
         """Empty queue test"""
         q = self.queue()
         assert q.pop() is None
+        q.close()
 
     def test_single_pushpop(self):
         q = self.queue()
         q.push(b"a")
         assert q.pop() == b"a"
+        q.close()
 
     def test_binary_element(self):
         elem = (
@@ -101,27 +103,30 @@ class QueueTestMixin:
         q = self.queue()
         q.push(elem)
         assert q.pop() == elem
+        q.close()
 
     def test_len(self):
         q = self.queue()
-        self.assertEqual(len(q), 0)
+        assert len(q) == 0
         q.push(b"a")
-        self.assertEqual(len(q), 1)
+        assert len(q) == 1
         q.push(b"b")
         q.push(b"c")
-        self.assertEqual(len(q), 3)
+        assert len(q) == 3
         q.pop()
         q.pop()
         q.pop()
-        self.assertEqual(len(q), 0)
+        assert len(q) == 0
+        q.close()
 
     def test_peek_one_element(self):
         q = self.queue()
-        self.assertIsNone(q.peek())
+        assert q.peek() is None
         q.push(b"a")
-        self.assertEqual(q.peek(), b"a")
-        self.assertEqual(q.pop(), b"a")
-        self.assertIsNone(q.peek())
+        assert q.peek() == b"a"
+        assert q.pop() == b"a"
+        assert q.peek() is None
+        q.close()
 
 
 class FifoTestMixin:
@@ -131,10 +136,11 @@ class FifoTestMixin:
         q.push(b"a")
         q.push(b"b")
         q.push(b"c")
-        self.assertEqual(q.pop(), b"a")
-        self.assertEqual(q.pop(), b"b")
-        self.assertEqual(q.pop(), b"c")
-        self.assertEqual(q.pop(), None)
+        assert q.pop() == b"a"
+        assert q.pop() == b"b"
+        assert q.pop() == b"c"
+        assert q.pop() is None
+        q.close()
 
     def test_push_pop2(self):
         """Test interleaved push and pops"""
@@ -143,29 +149,31 @@ class FifoTestMixin:
         q.push(b"b")
         q.push(b"c")
         q.push(b"d")
-        self.assertEqual(q.pop(), b"a")
-        self.assertEqual(q.pop(), b"b")
+        assert q.pop() == b"a"
+        assert q.pop() == b"b"
         q.push(b"e")
-        self.assertEqual(q.pop(), b"c")
-        self.assertEqual(q.pop(), b"d")
-        self.assertEqual(q.pop(), b"e")
+        assert q.pop() == b"c"
+        assert q.pop() == b"d"
+        assert q.pop() == b"e"
+        q.close()
 
     def test_peek_fifo(self):
         q = self.queue()
-        self.assertIsNone(q.peek())
+        assert q.peek() is None
         q.push(b"a")
         q.push(b"b")
         q.push(b"c")
-        self.assertEqual(q.peek(), b"a")
-        self.assertEqual(q.peek(), b"a")
-        self.assertEqual(q.pop(), b"a")
-        self.assertEqual(q.peek(), b"b")
-        self.assertEqual(q.peek(), b"b")
-        self.assertEqual(q.pop(), b"b")
-        self.assertEqual(q.peek(), b"c")
-        self.assertEqual(q.peek(), b"c")
-        self.assertEqual(q.pop(), b"c")
-        self.assertIsNone(q.peek())
+        assert q.peek() == b"a"
+        assert q.peek() == b"a"
+        assert q.pop() == b"a"
+        assert q.peek() == b"b"
+        assert q.peek() == b"b"
+        assert q.pop() == b"b"
+        assert q.peek() == b"c"
+        assert q.peek() == b"c"
+        assert q.pop() == b"c"
+        assert q.peek() is None
+        q.close()
 
 
 class LifoTestMixin:
@@ -175,10 +183,11 @@ class LifoTestMixin:
         q.push(b"a")
         q.push(b"b")
         q.push(b"c")
-        self.assertEqual(q.pop(), b"c")
-        self.assertEqual(q.pop(), b"b")
-        self.assertEqual(q.pop(), b"a")
-        self.assertEqual(q.pop(), None)
+        assert q.pop() == b"c"
+        assert q.pop() == b"b"
+        assert q.pop() == b"a"
+        assert q.pop() is None
+        q.close()
 
     def test_push_pop2(self):
         """Test interleaved push and pops"""
@@ -187,42 +196,50 @@ class LifoTestMixin:
         q.push(b"b")
         q.push(b"c")
         q.push(b"d")
-        self.assertEqual(q.pop(), b"d")
-        self.assertEqual(q.pop(), b"c")
+        assert q.pop() == b"d"
+        assert q.pop() == b"c"
         q.push(b"e")
-        self.assertEqual(q.pop(), b"e")
-        self.assertEqual(q.pop(), b"b")
-        self.assertEqual(q.pop(), b"a")
+        assert q.pop() == b"e"
+        assert q.pop() == b"b"
+        assert q.pop() == b"a"
+        q.close()
 
     def test_peek_lifo(self):
         q = self.queue()
-        self.assertIsNone(q.peek())
+        assert q.peek() is None
         q.push(b"a")
         q.push(b"b")
         q.push(b"c")
-        self.assertEqual(q.peek(), b"c")
-        self.assertEqual(q.peek(), b"c")
-        self.assertEqual(q.pop(), b"c")
-        self.assertEqual(q.peek(), b"b")
-        self.assertEqual(q.peek(), b"b")
-        self.assertEqual(q.pop(), b"b")
-        self.assertEqual(q.peek(), b"a")
-        self.assertEqual(q.peek(), b"a")
-        self.assertEqual(q.pop(), b"a")
-        self.assertIsNone(q.peek())
+        assert q.peek() == b"c"
+        assert q.peek() == b"c"
+        assert q.pop() == b"c"
+        assert q.peek() == b"b"
+        assert q.peek() == b"b"
+        assert q.pop() == b"b"
+        assert q.peek() == b"a"
+        assert q.peek() == b"a"
+        assert q.pop() == b"a"
+        assert q.peek() is None
+        q.close()
 
 
 class PersistentTestMixin:
-
     chunksize = 100000
 
-    @pytest.mark.xfail(reason="Reenable once Scrapy.squeues stops extending from this testsuite")
+    @pytest.mark.xfail(
+        reason="Reenable once Scrapy.squeues stops extending from this testsuite"
+    )
     def test_non_bytes_raises_typeerror(self):
         q = self.queue()
-        self.assertRaises(TypeError, q.push, 0)
-        self.assertRaises(TypeError, q.push, u"")
-        self.assertRaises(TypeError, q.push, None)
-        self.assertRaises(TypeError, q.push, lambda x: x)
+        with pytest.raises(TypeError):
+            q.push(0)
+        with pytest.raises(TypeError):
+            q.push("")
+        with pytest.raises(TypeError):
+            q.push(None)
+        with pytest.raises(TypeError):
+            q.push(lambda x: x)
+        q.close()
 
     def test_text_in_windows(self):
         e1 = b"\r\n"
@@ -231,7 +248,8 @@ class PersistentTestMixin:
         q.close()
         q = self.queue()
         e2 = q.pop()
-        self.assertEqual(e1, e2)
+        assert e1 == e2
+        q.close()
 
     def test_close_open(self):
         """Test closing and re-opening keeps state"""
@@ -246,7 +264,7 @@ class PersistentTestMixin:
         del q
 
         q = self.queue()
-        self.assertEqual(len(q), 2)
+        assert len(q) == 2
         q.push(b"e")
         q.pop()
         q.pop()
@@ -255,20 +273,21 @@ class PersistentTestMixin:
 
         q = self.queue()
         assert q.pop() is not None
-        self.assertEqual(len(q), 0)
+        assert len(q) == 0
+        q.close()
 
     def test_cleanup(self):
         """Test queue dir is removed if queue is empty"""
         q = self.queue()
         values = [b"0", b"1", b"2", b"3", b"4"]
-        assert os.path.exists(self.qpath)
+        assert self.qpath.exists()
         for x in values:
             q.push(x)
 
-        for x in values:
+        for _ in values:
             q.pop()
         q.close()
-        assert not os.path.exists(self.qpath)
+        assert not self.qpath.exists()
 
 
 class FifoMemoryQueueTest(FifoTestMixin, QueueTestMixin, QueuelibTestCase):
@@ -281,18 +300,22 @@ class LifoMemoryQueueTest(LifoTestMixin, QueueTestMixin, QueuelibTestCase):
         return LifoMemoryQueue()
 
 
-class FifoDiskQueueTest(FifoTestMixin, PersistentTestMixin, QueueTestMixin, QueuelibTestCase):
+class FifoDiskQueueTest(
+    FifoTestMixin, PersistentTestMixin, QueueTestMixin, QueuelibTestCase
+):
     def queue(self):
         return FifoDiskQueue(self.qpath, chunksize=self.chunksize)
 
     def test_not_szhdr(self):
         q = self.queue()
         q.push(b"something")
-        empty_file = open(self.tempfilename(), "w+")
-        with mock.patch.object(q, "tailf", empty_file):
+        with (
+            self.tempfilename().open("w+") as empty_file,
+            mock.patch.object(q, "tailf", empty_file),
+        ):
             assert q.peek() is None
             assert q.pop() is None
-        empty_file.close()
+        q.close()
 
     def test_chunks(self):
         """Test chunks are created and removed"""
@@ -301,13 +324,14 @@ class FifoDiskQueueTest(FifoTestMixin, PersistentTestMixin, QueueTestMixin, Queu
         for x in values:
             q.push(x)
 
-        chunks = glob.glob(os.path.join(self.qpath, "q*"))
-        self.assertEqual(len(chunks), 5 // self.chunksize + 1)
-        for x in values:
+        chunks = list(self.qpath.glob("q*"))
+        assert len(chunks) == 5 // self.chunksize + 1
+        for _ in values:
             q.pop()
 
-        chunks = glob.glob(os.path.join(self.qpath, "q*"))
-        self.assertEqual(len(chunks), 1)
+        chunks = list(self.qpath.glob("q*"))
+        assert len(chunks) == 1
+        q.close()
 
 
 class ChunkSize1FifoDiskQueueTest(FifoDiskQueueTest):
@@ -326,7 +350,9 @@ class ChunkSize4FifoDiskQueueTest(FifoDiskQueueTest):
     chunksize = 4
 
 
-class LifoDiskQueueTest(LifoTestMixin, PersistentTestMixin, QueueTestMixin, QueuelibTestCase):
+class LifoDiskQueueTest(
+    LifoTestMixin, PersistentTestMixin, QueueTestMixin, QueuelibTestCase
+):
     def queue(self):
         return LifoDiskQueue(self.qpath)
 
@@ -336,18 +362,22 @@ class LifoDiskQueueTest(LifoTestMixin, PersistentTestMixin, QueueTestMixin, Queu
         q.push(b"a")
         q.push(b"b")
         q.close()
-        size = os.path.getsize(self.qpath)
+        size = self.qpath.stat().st_size
         q = self.queue()
         q.pop()
         q.close()
-        assert os.path.getsize(self.qpath), size
+        assert self.qpath.stat().st_size, size
 
 
-class FifoSQLiteQueueTest(FifoTestMixin, PersistentTestMixin, QueueTestMixin, QueuelibTestCase):
+class FifoSQLiteQueueTest(
+    FifoTestMixin, PersistentTestMixin, QueueTestMixin, QueuelibTestCase
+):
     def queue(self):
         return FifoSQLiteQueue(self.qpath)
 
 
-class LifoSQLiteQueueTest(LifoTestMixin, PersistentTestMixin, QueueTestMixin, QueuelibTestCase):
+class LifoSQLiteQueueTest(
+    LifoTestMixin, PersistentTestMixin, QueueTestMixin, QueuelibTestCase
+):
     def queue(self):
         return LifoSQLiteQueue(self.qpath)
